@@ -1,28 +1,31 @@
 /* SPDX-License-Identifier: Zlib */
 
-#include <girara/log.h>
-#include <girara/session.h>
-#include <girara/settings.h>
-#include <girara/datastructures.h>
-#include <girara/shortcuts.h>
-#include <girara/utils.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
-#include "callbacks.h"
 #include "shortcuts.h"
+
+#include <girara-gtk/internal.h>
+#include <girara-gtk/session.h>
+#include <girara-gtk/settings.h>
+#include <girara-gtk/shortcuts.h>
+#include <girara/datastructures.h>
+#include <girara/log.h>
+#include <girara/utils.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <math.h>
+
+#include "adjustment.h"
+#include "callbacks.h"
+#include "commands.h"
+#include "database.h"
 #include "dbus-interface.h"
+#include "document-widget.h"
 #include "document.h"
-#include "zathura.h"
-#include "render.h"
-#include "utils.h"
+#include "page-widget.h"
 #include "page.h"
 #include "print.h"
-#include "page-widget.h"
-#include "adjustment.h"
-#include "database.h"
-#include "document-widget.h"
-#include <math.h>
+#include "render.h"
+#include "utils.h"
+#include "zathura.h"
 
 /* Helper function for highlighting the links */
 static bool draw_links(zathura_t* zathura) {
@@ -1366,7 +1369,25 @@ bool sc_zoom(girara_session_t* session, girara_argument_t* argument, girara_even
   return false;
 }
 
-bool sc_exec(girara_session_t* session, girara_argument_t* argument, girara_event_t* event, unsigned int t) {
+static bool sc_exec_internal(girara_session_t* session, girara_argument_t* argument) {
+  if (argument == NULL || argument->data == NULL) {
+    return false;
+  }
+
+  /* create argument list */
+  g_autoptr(girara_list_t) argument_list = argument_to_argument_list(argument);
+  if (argument_list == NULL) {
+    return false;
+  }
+
+  /* call exec */
+  cmd_exec(session, argument_list);
+
+  return false;
+}
+
+bool sc_exec(girara_session_t* session, girara_argument_t* argument, girara_event_t* UNUSED(event),
+             unsigned int UNUSED(t)) {
   g_return_val_if_fail(session != NULL, false);
   g_return_val_if_fail(session->global.data != NULL, false);
   zathura_t* zathura = session->global.data;
@@ -1406,7 +1427,7 @@ bool sc_exec(girara_session_t* session, girara_argument_t* argument, girara_even
     new_argument.data = s;
   }
 
-  const bool ret = girara_sc_exec(session, &new_argument, event, t);
+  const bool ret = sc_exec_internal(session, &new_argument);
   g_free(new_argument.data);
   return ret;
 }
